@@ -17,6 +17,8 @@ class Config:
     SSL_DISABLE = False
     SQLALCHEMY_COMMIT_ON_TEARDOWN = True
     SQLALCHEMY_RECORD_QUERIES = True
+    SQLALCHEMY_TRACK_MODIFICATIONS = True
+
     @staticmethod
     def init_app(app):
         pass
@@ -25,22 +27,19 @@ class Config:
 class DevelopmentConfig(Config):
     """开发环境配置类"""
     DEBUG = True
-    SQLALCHEMY_DATABASE_URI = os.environ.get("DEV_DATABASE_URL") or\
-        "sqlite:///" + os.path.join(basedir, "data-dev.sqlite")
+    SQLALCHEMY_DATABASE_URI = os.environ.get("DEV_DATABASE_URL") or "sqlite:///" + os.path.join(basedir, "data-dev.sqlite")
 
 
 class TestingConfig(Config):
     """测试环境配置类"""
     TESTING = True
-    SQLALCHEMY_DATABASE_URI = os.environ.get("TEST_DATABASE_URL") or\
-        "sqlite:///" + os.path.join(basedir, "data-test.sqlite")
+    SQLALCHEMY_DATABASE_URI = os.environ.get("TEST_DATABASE_URL") or "sqlite:///" + os.path.join(basedir, "data-test.sqlite")
     WTF_CSRF_ENABLED = False
 
 
 class ProductionConfig(Config):
     """生产环境配置类"""
-    SQLALCHEMY_DATABASE_URI = os.environ.get("DATABASE_URL") or\
-        "sqlite:///" + os.path.join(basedir, "data.sqlite")
+    SQLALCHEMY_DATABASE_URI = os.environ.get("DATABASE_URL") or "sqlite:///" + os.path.join(basedir, "data.sqlite")
     @classmethod
     def init_app(cls, app):
         Config.init_app(app)
