@@ -1,4 +1,4 @@
 # coding: utf-8
 
 from _manage_basic import _manage_basic_code
-from _manage_sql import _manage_sql_code
+from _manage_admin import _manage_admin_code
